## Aliyun ROS DASHVECTOR Construct Library

This module is part of the AliCloud ROS Cloud Development Kit (ROS CDK) project.

```python
import * as DASHVECTOR from '@alicloud/ros-cdk-dashvector';
```
